VarInt

Struct VarInt 

pub struct VarInt(pub u64);
Variable-integer encoding.

Integer can be encoded depending on the represented value to save space. Variable length integers always precede an array/vector of a type of data that may vary in length. Longer numbers are encoded in little endian.

ValueStorage lengthFormat
<= 0xfc1u8
<= 0xffff30xfd followed by value as u16
<= 0xffffffff50xfe followed by value as u32
-90xff followed by value as u64

See also Bitcoin variable length integers.

Tuple Fields

0: u64

Implementations

Source

impl VarInt

pub fn length(&self) -> usize

Gets the length of this VarInt when encoded. Returns:

  • 1 for 0..0xFC
  • 3 for 0xFD..(2^16-1)
  • 5 for 0x10000..(2^32-1)
  • 9 otherwise